# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.1] - 2024-09-1

- This release has no changes, it is just to trigger the release process since
  the initial release on PyPi did not include the archive which is needed for
  `conda-forge` to build the package.

## [0.1.0] - 2024-08-31

- Initial release.
